/*
  HelloAI - A simple example for the Arduino AI Assistant library.
  This example demonstrates how to use the Arduino AI Assistant
  to get help with your Arduino projects.
  
  The Arduino AI Assistant helps you generate AI-powered code
  and get explanations for existing code through its web interface.
  
  Created: April, 2025
*/

#include <ArduinoAIAssistant.h>

// Create an instance of the AI Assistant
ArduinoAIAssistant aiAssistant;

void setup() {
  // Initialize serial communication
  Serial.begin(9600);
  
  // Wait for serial port to connect (important for native USB port)
  while (!Serial) {
    ; // wait for serial port to connect
  }
  
  // Initialize the AI Assistant
  aiAssistant.begin();
  
  // Welcome message
  Serial.println("Arduino AI Assistant Example");
  Serial.println("---------------------------");
  
  // Print help information
  aiAssistant.printHelp();
  
  // Print the web app link
  aiAssistant.printWebAppLink();
  
  // Add a code comment for reference
  aiAssistant.addCodeComment();
  
  Serial.println("\nOpen the Serial Monitor to see the output");
}

void loop() {
  // Check if there's any serial input
  if (Serial.available() > 0) {
    // Read the incoming byte
    String input = Serial.readStringUntil('\n');
    
    // Process commands
    if (input == "help") {
      aiAssistant.printHelp();
    } 
    else if (input == "link") {
      aiAssistant.printWebAppLink();
    }
    else {
      Serial.println("Unknown command. Type 'help' or 'link'");
    }
  }
  
  // Small delay to prevent busy-waiting
  delay(100);
}