/*
  SimpleAIChat - Basic AI Assistant in Serial Monitor
  
  This example shows how to add AI Assistant functionality
  to your Arduino project with minimal code.
  
  INSTRUCTIONS:
  1. Upload this sketch to your Arduino
  2. Open Serial Monitor (Tools > Serial Monitor)
  3. Type commands and see the AI Assistant respond
  
  Created: April, 2025
*/

#include <ArduinoAIAssistant.h>

// Create an instance of the AI Assistant
ArduinoAIAssistant aiAssistant;

void setup() {
  // Set up Serial communication
  Serial.begin(9600);
  
  // Wait for Serial to be ready
  delay(1000);
  
  // Display welcome message
  Serial.println("\n\n");
  Serial.println("========================================");
  Serial.println("  Arduino AI Assistant - Serial Chat");
  Serial.println("========================================");
  Serial.println("Type commands in the input box above and");
  Serial.println("press SEND to interact with the assistant.");
  Serial.println();
  Serial.println("Try these commands:");
  Serial.println("- help     : Show available commands");
  Serial.println("- chat     : Enter chat mode with AI");
  Serial.println("- led      : Generate LED blink code");
  Serial.println("- button   : Generate button code");
  Serial.println("- sensor   : Generate sensor code");
  Serial.println("- servo    : Generate servo code");
  Serial.println("========================================");
  
  // Initialize the AI Assistant
  aiAssistant.begin();
}

void loop() {
  // This is all you need to handle the AI Assistant commands
  aiAssistant.handleSerialInput();
  
  // Small delay to prevent busy-waiting
  delay(50);
}