#!/bin/bash
echo "Coduino AI Assistant Desktop App Installer"
echo "================================================="
echo "Founded by Houcine Benslimane"
echo

# Check if npm is installed
if ! command -v npm &> /dev/null; then
    echo "ERROR: npm is not installed. Please install Node.js and npm first."
    echo "Visit https://nodejs.org/ for installation instructions."
    exit 1
fi

echo "Installing dependencies..."
npm install axios electron

# Detect desktop environment and create appropriate shortcut
DESKTOP_FILE="$HOME/.local/share/applications/coduino-ai-assistant.desktop"
ICON_PATH="$(pwd)/generated-icon.png"
APP_PATH="$(pwd)"

echo "Creating application shortcut..."
mkdir -p "$HOME/.local/share/applications"

cat > "$DESKTOP_FILE" << EOL
[Desktop Entry]
Type=Application
Name=Coduino AI Assistant
Comment=AI-powered code generation for Arduino - Founded by Houcine Benslimane
Exec=npx electron "$APP_PATH"
Icon=$ICON_PATH
Terminal=false
Categories=Development;Electronics;
EOL

chmod +x "$DESKTOP_FILE"

# Create desktop shortcut (symlink)
echo "Creating desktop shortcut..."
if [ -d "$HOME/Desktop" ]; then
    ln -sf "$DESKTOP_FILE" "$HOME/Desktop/Coduino AI Assistant.desktop"
    chmod +x "$HOME/Desktop/Coduino AI Assistant.desktop"
else
    echo "Could not create desktop shortcut: Desktop directory not found"
fi

echo "Starting Coduino AI Assistant..."
npx electron "$APP_PATH" &

echo
echo "Installation complete!"
echo "You can now launch Coduino AI Assistant from your desktop shortcut or by running:"
echo "npx electron "$APP_PATH""
echo
