const { app, BrowserWindow, ipcMain, clipboard, session } = require('electron');
const path = require('path');
const url = require('url');

// Allow require in renderer for API client
app.allowRendererProcessReuse = false;

// Keep a global reference of the window object to avoid garbage collection
let mainWindow;

function createWindow() {
  // Create the browser window
  mainWindow = new BrowserWindow({
    width: 400,
    height: 600,
    minWidth: 300,
    minHeight: 400,
    frame: false, // Frameless window for modern look
    transparent: true, // Enables transparency for rounded corners
    alwaysOnTop: true, // Keep window above other windows
    webPreferences: {
      nodeIntegration: false,
      contextIsolation: true,
      enableRemoteModule: false,
      preload: path.join(__dirname, 'preload.js'),
      worldSafeExecuteJavaScript: true,
      // Allow loading of local resources
      webSecurity: false
    }
  });

  // Load the index.html of the app
  mainWindow.loadURL(url.format({
    pathname: path.join(__dirname, 'index.html'),
    protocol: 'file:',
    slashes: true
  }));

  // Open DevTools in development mode
  // mainWindow.webContents.openDevTools();

  // Event handler for when the window is closed
  mainWindow.on('closed', function () {
    mainWindow = null;
  });
}

// Create window when Electron has finished initialization
app.on('ready', createWindow);

// Quit when all windows are closed
app.on('window-all-closed', function () {
  // On macOS applications keep their menu bar active until Cmd + Q
  if (process.platform !== 'darwin') {
    app.quit();
  }
});

app.on('activate', function () {
  // On macOS, re-create the window when dock icon is clicked and no windows are open
  if (mainWindow === null) {
    createWindow();
  }
});

// Listen for events from the renderer process
ipcMain.on('minimize-window', () => {
  console.log('Minimize window requested');
  if (mainWindow) {
    mainWindow.minimize();
  }
});

ipcMain.on('close-window', () => {
  console.log('Close window requested');
  if (mainWindow) {
    mainWindow.close();
    // Force quit if necessary (especially on Windows)
    if (process.platform !== 'darwin') {
      app.quit();
    }
  }
});

ipcMain.on('toggle-always-on-top', (event, flag) => {
  console.log('Toggle always on top:', flag);
  if (mainWindow) {
    mainWindow.setAlwaysOnTop(flag);
  }
});

// Handle clipboard copying
ipcMain.on('copy-to-clipboard', (event, text) => {
  clipboard.writeText(text);
});