// Preload script runs in Electron before the renderer process
// It has access to Node.js APIs and can communicate with the main process
const { contextBridge, ipcRenderer } = require('electron');
const path = require('path');
const axios = require('axios');

// Expose the axios library to the renderer process
contextBridge.exposeInMainWorld('axios', axios);

// Expose Node.js modules needed for the API client
contextBridge.exposeInMainWorld('nodePath', path);
contextBridge.exposeInMainWorld('nodeRequire', (module) => {
  // Whitelist allowed modules
  const allowedModules = ['axios', './api-client'];
  if (allowedModules.includes(module) || module.startsWith('./')) {
    try {
      return require(module);
    } catch (e) {
      console.error(`Error requiring module ${module}:`, e);
      return null;
    }
  }
  return null;
});

// Expose protected methods that allow the renderer process to use
// the ipcRenderer without exposing the entire object
contextBridge.exposeInMainWorld(
  'electronAPI', {
    // Send messages to main process
    sendToMain: (channel, data) => {
      // Whitelist channels
      const validChannels = ['minimize-window', 'close-window', 'toggle-always-on-top', 'copy-to-clipboard'];
      if (validChannels.includes(channel)) {
        ipcRenderer.send(channel, data);
      }
    },
    // Receive messages from main process
    receiveFromMain: (channel, func) => {
      const validChannels = ['api-response'];
      if (validChannels.includes(channel)) {
        ipcRenderer.on(channel, (event, ...args) => func(...args));
      }
    }
  }
);

window.addEventListener('DOMContentLoaded', () => {
  console.log('DOM Content loaded in preload.js');
  
  // Expose versions info if needed
  const replaceText = (selector, text) => {
    const element = document.getElementById(selector);
    if (element) element.innerText = text;
  };

  // Add version info if needed
  for (const dependency of ['chrome', 'node', 'electron']) {
    replaceText(`${dependency}-version`, process.versions[dependency]);
  }
});